@@ -12,7 +12,18 @@ from .utils.cli_utils import show_info
 from .version import __version__
 import featuretools.demo
 from . import feature_base
-from .feature_base import AggregationFeature, DirectFeature, Feature, FeatureBase, IdentityFeature, TransformFeature, GroupByTransformFeature, save_features, load_features
+from .feature_base import (
+    AggregationFeature,
+    DirectFeature,
+    Feature,
+    FeatureBase,
+    GroupByTransformFeature,
+    IdentityFeature,
+    TransformFeature,
+    graph_feature,
+    save_features,
+    load_features
+)
 
 import logging
 import pkg_resources
