@@ -1,5 +1,6 @@
 import copy
 import logging
+import warnings
 from collections import defaultdict
 
 import dask.dataframe as dd
@@ -239,8 +240,8 @@ class EntitySet(object):
                 relationship to be added.
         """
         if relationship in self.relationships:
-            logger.warning(
-                "Not adding duplicate relationship: %s", relationship)
+            warnings.warn(
+                "Not adding duplicate relationship: " + str(relationship))
             return self
 
         # _operations?
@@ -924,8 +925,11 @@ class EntitySet(object):
         for entity in self.entities:
             variables_string = '\l'.join([var.id + ' : ' + var.type_string  # noqa: W605
                                           for var in entity.variables])
-            nrows = entity.shape[0]
-            label = '{%s (%d row%s)|%s\l}' % (entity.id, nrows, 's' * (nrows > 1), variables_string)  # noqa: W605
+            if isinstance(entity.df, dd.DataFrame):  # entity is a dask entity
+                label = '{%s |%s\l}' % (entity.id, variables_string)  # noqa: W605
+            else:
+                nrows = entity.shape[0]
+                label = '{%s (%d row%s)|%s\l}' % (entity.id, nrows, 's' * (nrows > 1), variables_string)  # noqa: W605
             graph.node(entity.id, shape='record', label=label)
 
         # Draw relationships
