@@ -1,3 +1,5 @@
+import warnings
+
 import dask.dataframe as dd
 import numpy as np
 import pandas as pd
@@ -212,6 +214,11 @@ class Week(TransformPrimitive):
 
     def get_function(self):
         def week(vals):
+            warnings.filterwarnings("ignore",
+                                    message=("Series.dt.weekofyear and Series.dt.week "
+                                             "have been deprecated."),
+                                    module="featuretools"
+                                    )
             return vals.dt.week
         return week
 
@@ -387,7 +394,7 @@ class TimeSince(TransformPrimitive):
         [-1000, -1000000000, -120000000000]
     """
     name = 'time_since'
-    input_types = [[DatetimeTimeIndex], [Datetime]]
+    input_types = [Datetime]
     return_type = Numeric
     uses_calc_time = True
     dask_compatible = True
