@@ -1,4 +1,4 @@
-import copy
+import logging
 import os
 import re
 import shutil
@@ -48,11 +48,14 @@ from featuretools.tests.testing_utils import (
 )
 
 
-def test_scatter_warning():
-    match = r'EntitySet was only scattered to .* out of .* workers'
-    with pytest.warns(UserWarning, match=match) as record:
-        scatter_warning(1, 2)
-    assert len(record) == 1
+def test_scatter_warning(caplog):
+    logger = logging.getLogger('featuretools')
+    match = "EntitySet was only scattered to {} out of {} workers"
+    warning_message = match.format(1, 2)
+    logger.propagate = True
+    scatter_warning(1, 2)
+    logger.propagate = False
+    assert warning_message in caplog.text
 
 
 # TODO: final assert fails w/ Dask
@@ -468,10 +471,12 @@ def test_training_window(pd_es):
              datetime(2011, 4, 10, 11),
              datetime(2011, 4, 10, 13, 10)]
     cutoff_time = pd.DataFrame({'time': times, 'instance_id': [0, 1, 2]})
-    feature_matrix = calculate_feature_matrix([property_feature, dagg],
-                                              pd_es,
-                                              cutoff_time=cutoff_time,
-                                              training_window='2 hours')
+    warn_text = "Using training_window but last_time_index is not set on entity customers"
+    with pytest.warns(UserWarning, match=warn_text):
+        feature_matrix = calculate_feature_matrix([property_feature, dagg],
+                                                  pd_es,
+                                                  cutoff_time=cutoff_time,
+                                                  training_window='2 hours')
 
     pd_es.add_last_time_indexes()
 
@@ -1049,7 +1054,6 @@ def test_cutoff_time_naming(es):
 
 
 # TODO: order doesn't match, but output matches
-# TODO: split out approximate test into seperate test for only pandas
 def test_cutoff_time_extra_columns(es):
     if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
         pytest.xfail('Dask result not ordered')
@@ -1070,15 +1074,25 @@ def test_cutoff_time_extra_columns(es):
 
     assert (fm['label'].values == cutoff_df['label'].values).all()
 
-    if any(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
-        fm_2 = calculate_feature_matrix([dfeat],
-                                        es,
-                                        cutoff_time=cutoff_df,
-                                        approximate="2 days")
-        # check column was added to end of matrix
-        assert 'label' in fm_2.columns
 
-        assert (fm_2['label'].values == cutoff_df['label'].values).all()
+def test_cutoff_time_extra_columns_approximate(pd_es):
+    agg_feat = ft.Feature(pd_es['customers']['id'], parent_entity=pd_es[u'régions'], primitive=Count)
+    dfeat = DirectFeature(agg_feat, pd_es['customers'])
+
+    cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
+                                       pd.Timestamp('2011-04-09 10:30:03'),
+                                       pd.Timestamp('2011-04-08 10:30:00')],
+                              'instance_id': [0, 1, 0],
+                              'label': [True, True, False]},
+                             columns=['time', 'instance_id', 'label'])
+    fm = calculate_feature_matrix([dfeat],
+                                  pd_es,
+                                  cutoff_time=cutoff_df,
+                                  approximate="2 days")
+    # check column was added to end of matrix
+    assert 'label' in fm.columns
+
+    assert (fm['label'].values == cutoff_df['label'].values).all()
 
 
 def test_instances_after_cutoff_time_removed(es):
@@ -1121,19 +1135,16 @@ def test_instances_with_id_kept_after_cutoff(es):
 
 
 # TODO: Fails with Dask
-# TODO: split out approximate portion into seperate test for pandas
 def test_cfm_returns_original_time_indexes(es):
     if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
         pytest.xfail('Dask result not ordered, indexes are lost due to not multiindexing')
     agg_feat = ft.Feature(es['customers']['id'], parent_entity=es[u'régions'], primitive=Count)
     dfeat = DirectFeature(agg_feat, es['customers'])
-    agg_feat_2 = ft.Feature(es['sessions']['id'], parent_entity=es['customers'], primitive=Count)
     cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
                                        pd.Timestamp('2011-04-09 10:30:03'),
                                        pd.Timestamp('2011-04-08 10:30:00')],
                               'instance_id': [0, 1, 0]})
 
-    # no approximate
     fm = calculate_feature_matrix([dfeat],
                                   es, cutoff_time=cutoff_df,
                                   cutoff_time_in_index=True)
@@ -1148,39 +1159,46 @@ def test_cfm_returns_original_time_indexes(es):
     assert (instance_level_vals == cutoff_df['instance_id'].values).all()
     assert (time_level_vals == cutoff_df['time'].values).all()
 
-    # skip approximate for Dask
-    if any(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
-        # approximate, in different windows, no unapproximated aggs
-        fm2 = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df,
-                                       cutoff_time_in_index=True, approximate="1 m")
-        instance_level_vals = fm2.index.get_level_values(0).values
-        time_level_vals = fm2.index.get_level_values(1).values
-        assert (instance_level_vals == cutoff_df['instance_id'].values).all()
-        assert (time_level_vals == cutoff_df['time'].values).all()
 
-        # approximate, in different windows, unapproximated aggs
-        fm2 = calculate_feature_matrix([dfeat, agg_feat_2], es, cutoff_time=cutoff_df,
-                                       cutoff_time_in_index=True, approximate="1 m")
-        instance_level_vals = fm2.index.get_level_values(0).values
-        time_level_vals = fm2.index.get_level_values(1).values
-        assert (instance_level_vals == cutoff_df['instance_id'].values).all()
-        assert (time_level_vals == cutoff_df['time'].values).all()
+def test_cfm_returns_original_time_indexes_approximate(pd_es):
+    agg_feat = ft.Feature(pd_es['customers']['id'], parent_entity=pd_es[u'régions'], primitive=Count)
+    dfeat = DirectFeature(agg_feat, pd_es['customers'])
+    agg_feat_2 = ft.Feature(pd_es['sessions']['id'], parent_entity=pd_es['customers'], primitive=Count)
+    cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
+                                       pd.Timestamp('2011-04-09 10:30:03'),
+                                       pd.Timestamp('2011-04-08 10:30:00')],
+                              'instance_id': [0, 1, 0]})
+    # approximate, in different windows, no unapproximated aggs
+    fm = calculate_feature_matrix([dfeat], pd_es, cutoff_time=cutoff_df,
+                                  cutoff_time_in_index=True, approximate="1 m")
+    instance_level_vals = fm.index.get_level_values(0).values
+    time_level_vals = fm.index.get_level_values(1).values
+    assert (instance_level_vals == cutoff_df['instance_id'].values).all()
+    assert (time_level_vals == cutoff_df['time'].values).all()
 
-        # approximate, in same window, no unapproximated aggs
-        fm3 = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df,
-                                       cutoff_time_in_index=True, approximate="2 d")
-        instance_level_vals = fm3.index.get_level_values(0).values
-        time_level_vals = fm3.index.get_level_values(1).values
-        assert (instance_level_vals == cutoff_df['instance_id'].values).all()
-        assert (time_level_vals == cutoff_df['time'].values).all()
+    # approximate, in different windows, unapproximated aggs
+    fm = calculate_feature_matrix([dfeat, agg_feat_2], pd_es, cutoff_time=cutoff_df,
+                                  cutoff_time_in_index=True, approximate="1 m")
+    instance_level_vals = fm.index.get_level_values(0).values
+    time_level_vals = fm.index.get_level_values(1).values
+    assert (instance_level_vals == cutoff_df['instance_id'].values).all()
+    assert (time_level_vals == cutoff_df['time'].values).all()
 
-        # approximate, in same window, unapproximated aggs
-        fm3 = calculate_feature_matrix([dfeat, agg_feat_2], es, cutoff_time=cutoff_df,
-                                       cutoff_time_in_index=True, approximate="2 d")
-        instance_level_vals = fm3.index.get_level_values(0).values
-        time_level_vals = fm3.index.get_level_values(1).values
-        assert (instance_level_vals == cutoff_df['instance_id'].values).all()
-        assert (time_level_vals == cutoff_df['time'].values).all()
+    # approximate, in same window, no unapproximated aggs
+    fm2 = calculate_feature_matrix([dfeat], pd_es, cutoff_time=cutoff_df,
+                                   cutoff_time_in_index=True, approximate="2 d")
+    instance_level_vals = fm2.index.get_level_values(0).values
+    time_level_vals = fm2.index.get_level_values(1).values
+    assert (instance_level_vals == cutoff_df['instance_id'].values).all()
+    assert (time_level_vals == cutoff_df['time'].values).all()
+
+    # approximate, in same window, unapproximated aggs
+    fm3 = calculate_feature_matrix([dfeat, agg_feat_2], pd_es, cutoff_time=cutoff_df,
+                                   cutoff_time_in_index=True, approximate="2 d")
+    instance_level_vals = fm3.index.get_level_values(0).values
+    time_level_vals = fm3.index.get_level_values(1).values
+    assert (instance_level_vals == cutoff_df['instance_id'].values).all()
+    assert (time_level_vals == cutoff_df['time'].values).all()
 
 
 def test_dask_kwargs(pd_es):
@@ -1516,24 +1534,6 @@ def test_string_time_values_in_cutoff_time(es):
         calculate_feature_matrix([agg_feature], es, cutoff_time=cutoff_time)
 
 
-@pytest.fixture
-def pd_mock_customer():
-    return ft.demo.load_mock_customer(return_entityset=True, random_seed=0)
-
-
-@pytest.fixture
-def dd_mock_customer(pd_mock_customer):
-    dd_mock_customer = copy.deepcopy(pd_mock_customer)
-    for entity in dd_mock_customer.entities:
-        entity.df = dd.from_pandas(entity.df.reset_index(drop=True), npartitions=4)
-    return dd_mock_customer
-
-
-@pytest.fixture(params=['pd_mock_customer', 'dd_mock_customer'])
-def mock_customer(request):
-    return request.getfixturevalue(request.param)
-
-
 # TODO: Dask version fails (feature matrix is empty)
 def test_no_data_for_cutoff_time(mock_customer):
     if any(isinstance(entity.df, dd.DataFrame) for entity in mock_customer.entities):
@@ -1620,6 +1620,16 @@ def test_some_instances_not_in_data(pd_es):
         np.testing.assert_array_equal(fm[x], y)
 
 
+def test_missing_instances_with_categorical_index(pd_es):
+    instance_ids = [0, 1, 3, 2]
+    features = ft.dfs(entityset=pd_es, target_entity='customers', features_only=True)
+    fm = ft.calculate_feature_matrix(entityset=pd_es,
+                                     features=features,
+                                     instance_ids=instance_ids)
+    assert all(fm.index.values == instance_ids)
+    assert isinstance(fm.index, pd.CategoricalIndex)
+
+
 def test_handle_chunk_size():
     total_size = 100
 
@@ -1665,7 +1675,6 @@ def test_chunk_dataframe_groups():
     assert fourth[0] == 3 and fourth[1].shape[0] == 1
 
 
-# TODO: split out cluster tests into seperate test for pandas
 def test_calls_progress_callback(mock_customer):
     class MockProgressCallback:
         def __init__(self):
@@ -1705,19 +1714,34 @@ def test_calls_progress_callback(mock_customer):
     assert np.isclose(mock_progress_callback.total_update, 100.0)
     assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
 
-    # test with multiple jobs, pandas only
-    if any(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
-        mock_progress_callback = MockProgressCallback()
 
-        with cluster() as (scheduler, [a, b]):
-            dkwargs = {'cluster': scheduler['address']}
-            ft.calculate_feature_matrix(features,
-                                        entityset=es,
-                                        progress_callback=mock_progress_callback,
-                                        dask_kwargs=dkwargs)
+def test_calls_progress_callback_cluster(pd_mock_customer):
+    class MockProgressCallback:
+        def __init__(self):
+            self.progress_history = []
+            self.total_update = 0
+            self.total_progress_percent = 0
 
-        assert np.isclose(mock_progress_callback.total_update, 100.0)
-        assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
+        def __call__(self, update, progress_percent, time_elapsed):
+            self.total_update += update
+            self.total_progress_percent = progress_percent
+            self.progress_history.append(progress_percent)
+
+    mock_progress_callback = MockProgressCallback()
+
+    trans_per_session = ft.Feature(pd_mock_customer["transactions"]["transaction_id"], parent_entity=pd_mock_customer["sessions"], primitive=Count)
+    trans_per_customer = ft.Feature(pd_mock_customer["transactions"]["transaction_id"], parent_entity=pd_mock_customer["customers"], primitive=Count)
+    features = [trans_per_session, ft.Feature(trans_per_customer, entity=pd_mock_customer["sessions"])]
+
+    with cluster() as (scheduler, [a, b]):
+        dkwargs = {'cluster': scheduler['address']}
+        ft.calculate_feature_matrix(features,
+                                    entityset=pd_mock_customer,
+                                    progress_callback=mock_progress_callback,
+                                    dask_kwargs=dkwargs)
+
+    assert np.isclose(mock_progress_callback.total_update, 100.0)
+    assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
 
 
 def test_closes_tqdm(es):
