@@ -8,6 +8,14 @@ import pytest
 import featuretools as ft
 
 
+@pytest.fixture
+def pd_simple():
+    es = ft.EntitySet("test")
+    df = pd.DataFrame({"foo": [1]})
+    es.entity_from_dataframe("test", df)
+    return es
+
+
 def test_returns_digraph_object(es):
     graph = es.plot()
 
@@ -41,18 +49,15 @@ def test_invalid_format(es):
     assert str(excinfo.value).startswith("Unknown format")
 
 
-def test_multiple_rows(es):
-    plot_ = es.plot()
+def test_multiple_rows(pd_es):
+    plot_ = pd_es.plot()
     result = re.findall(r"\((\d+\srows?)\)", plot_.source)
-    expected = ["{} rows".format(str(i.shape[0])) for i in es.entities]
+    expected = ["{} rows".format(str(i.shape[0])) for i in pd_es.entities]
     assert result == expected
 
 
-def test_single_row():
-    es = ft.EntitySet("test")
-    df = pd.DataFrame({"foo": [1]})
-    es.entity_from_dataframe("test", df)
-    plot_ = es.plot()
+def test_single_row(pd_simple):
+    plot_ = pd_simple.plot()
     result = re.findall(r"\((\d+\srows?)\)", plot_.source)
     expected = ["1 row"]
     assert result == expected
