@@ -10,8 +10,18 @@ from featuretools.computational_backends.calculate_feature_matrix import (
     FEATURE_CALCULATION_PERCENTAGE
 )
 from featuretools.entityset import EntitySet, Relationship, Timedelta
-from featuretools.primitives import Max, Mean, Min, Sum
+from featuretools.exceptions import UnusedPrimitiveWarning
+from featuretools.primitives import (
+    GreaterThanScalar,
+    Max,
+    Mean,
+    Min,
+    Sum,
+    make_agg_primitive,
+    make_trans_primitive
+)
 from featuretools.synthesis import dfs
+from featuretools.variable_types import Numeric
 
 
 @pytest.fixture(params=['pd_entities', 'dask_entities'])
@@ -235,28 +245,6 @@ def test_features_only(entities, relationships):
     assert len(features) > 0
 
 
-def test_dask_kwargs(pd_entities, relationships):
-    cutoff_times_df = pd.DataFrame({"instance_id": [1, 2, 3],
-                                    "time": [10, 12, 15]})
-    feature_matrix, features = dfs(entities=pd_entities,
-                                   relationships=relationships,
-                                   target_entity="transactions",
-                                   cutoff_time=cutoff_times_df)
-
-    with cluster() as (scheduler, [a, b]):
-        dask_kwargs = {'cluster': scheduler['address']}
-        feature_matrix_2, features_2 = dfs(entities=pd_entities,
-                                           relationships=relationships,
-                                           target_entity="transactions",
-                                           cutoff_time=cutoff_times_df,
-                                           dask_kwargs=dask_kwargs)
-
-    assert all(f1.unique_name() == f2.unique_name() for f1, f2 in zip(features, features_2))
-    for column in feature_matrix:
-        for x, y in zip(feature_matrix[column], feature_matrix_2[column]):
-            assert ((pd.isnull(x) and pd.isnull(y)) or (x == y))
-
-
 def test_accepts_relative_training_window(datetime_es):
     # TODO: Update to use Dask entities when issue #882 is closed
     feature_matrix, features = dfs(entityset=datetime_es,
@@ -323,8 +311,148 @@ def test_accepts_pd_dateoffset_training_window(datetime_es):
     assert (feature_matrix.index == feature_matrix_2.index).all()
 
 
-# TODO: split out cluster test to run on pandas seperately
-def test_calls_progress_callback(pd_entities, relationships):
+def test_warns_with_unused_primitives(es):
+    trans_primitives = ['num_characters', 'num_words', 'add_numeric']
+    agg_primitives = [Max, 'min']
+
+    warning_text = "Some specified primitives were not used during DFS:\n" + \
+        "  trans_primitives: ['add_numeric']\n  agg_primitives: ['max', 'min']\n" + \
+        "This may be caused by a using a value of max_depth that is too small, not setting interesting values, " + \
+        "or it may indicate no compatible variable types for the primitive were found in the data."
+
+    with pytest.warns(UnusedPrimitiveWarning) as record:
+        dfs(entityset=es,
+            target_entity='customers',
+            trans_primitives=trans_primitives,
+            agg_primitives=agg_primitives,
+            max_depth=1)
+
+    assert record[0].message.args[0] == warning_text
+
+    # Should not raise a warning
+    with pytest.warns(None) as record:
+        dfs(entityset=es,
+            target_entity='customers',
+            trans_primitives=trans_primitives,
+            agg_primitives=agg_primitives,
+            max_depth=2)
+
+    assert not record
+
+
+def test_does_not_warn_with_stacking_feature(pd_es):
+    with pytest.warns(None) as record:
+        dfs(entityset=pd_es,
+            target_entity='régions',
+            agg_primitives=['percent_true'],
+            trans_primitives=[GreaterThanScalar(5)],
+            primitive_options={'greater_than_scalar': {'include_entities': ['stores']}},
+            features_only=True)
+
+    assert not record
+
+
+def test_warns_with_unused_where_primitives(es):
+    warning_text = "Some specified primitives were not used during DFS:\n" + \
+        "  where_primitives: ['count', 'sum']\n" + \
+        "This may be caused by a using a value of max_depth that is too small, not setting interesting values, " + \
+        "or it may indicate no compatible variable types for the primitive were found in the data."
+
+    with pytest.warns(UnusedPrimitiveWarning) as record:
+        dfs(entityset=es,
+            target_entity='customers',
+            agg_primitives=['count'],
+            where_primitives=['sum', 'count'],
+            max_depth=1)
+
+    assert record[0].message.args[0] == warning_text
+
+
+def test_warns_with_unused_groupby_primitives(pd_es):
+    warning_text = "Some specified primitives were not used during DFS:\n" + \
+        "  groupby_trans_primitives: ['cum_sum']\n" + \
+        "This may be caused by a using a value of max_depth that is too small, not setting interesting values, " + \
+        "or it may indicate no compatible variable types for the primitive were found in the data."
+
+    with pytest.warns(UnusedPrimitiveWarning) as record:
+        dfs(entityset=pd_es,
+            target_entity='sessions',
+            groupby_trans_primitives=['cum_sum'],
+            max_depth=1)
+
+    assert record[0].message.args[0] == warning_text
+
+    # Should not raise a warning
+    with pytest.warns(None) as record:
+        dfs(entityset=pd_es,
+            target_entity='customers',
+            groupby_trans_primitives=['cum_sum'],
+            max_depth=1)
+
+    assert not record
+
+
+def test_warns_with_unused_custom_primitives(pd_es):
+    def above_ten(column):
+        return column > 10
+
+    AboveTen = make_trans_primitive(function=above_ten,
+                                    input_types=[Numeric],
+                                    return_type=Numeric)
+
+    trans_primitives = [AboveTen]
+
+    warning_text = "Some specified primitives were not used during DFS:\n" + \
+        "  trans_primitives: ['above_ten']\n" + \
+        "This may be caused by a using a value of max_depth that is too small, not setting interesting values, " + \
+        "or it may indicate no compatible variable types for the primitive were found in the data."
+
+    with pytest.warns(UnusedPrimitiveWarning) as record:
+        dfs(entityset=pd_es,
+            target_entity='sessions',
+            trans_primitives=trans_primitives,
+            max_depth=1)
+
+    assert record[0].message.args[0] == warning_text
+
+    # Should not raise a warning
+    with pytest.warns(None) as record:
+        dfs(entityset=pd_es,
+            target_entity='customers',
+            trans_primitives=trans_primitives,
+            max_depth=1)
+
+    def max_above_ten(column):
+        return max(column) > 10
+
+    MaxAboveTen = make_agg_primitive(function=max_above_ten,
+                                     input_types=[Numeric],
+                                     return_type=Numeric)
+
+    agg_primitives = [MaxAboveTen]
+
+    warning_text = "Some specified primitives were not used during DFS:\n" + \
+        "  agg_primitives: ['max_above_ten']\n" + \
+        "This may be caused by a using a value of max_depth that is too small, not setting interesting values, " + \
+        "or it may indicate no compatible variable types for the primitive were found in the data."
+
+    with pytest.warns(UnusedPrimitiveWarning) as record:
+        dfs(entityset=pd_es,
+            target_entity='stores',
+            agg_primitives=agg_primitives,
+            max_depth=1)
+
+    assert record[0].message.args[0] == warning_text
+
+    # Should not raise a warning
+    with pytest.warns(None) as record:
+        dfs(entityset=pd_es,
+            target_entity='sessions',
+            agg_primitives=agg_primitives,
+            max_depth=1)
+
+
+def test_calls_progress_callback(entities, relationships):
     class MockProgressCallback:
         def __init__(self):
             self.progress_history = []
@@ -338,7 +466,7 @@ def test_calls_progress_callback(pd_entities, relationships):
 
     mock_progress_callback = MockProgressCallback()
 
-    feature_matrix, features = dfs(entities=pd_entities,
+    feature_matrix, features = dfs(entities=entities,
                                    relationships=relationships,
                                    target_entity="transactions",
                                    progress_callback=mock_progress_callback)
@@ -348,7 +476,19 @@ def test_calls_progress_callback(pd_entities, relationships):
     assert np.isclose(mock_progress_callback.total_update, 100.0)
     assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
 
-    # test with multiple jobs
+
+def test_calls_progress_callback_cluster(pd_entities, relationships):
+    class MockProgressCallback:
+        def __init__(self):
+            self.progress_history = []
+            self.total_update = 0
+            self.total_progress_percent = 0
+
+        def __call__(self, update, progress_percent, time_elapsed):
+            self.total_update += update
+            self.total_progress_percent = progress_percent
+            self.progress_history.append(progress_percent)
+
     mock_progress_callback = MockProgressCallback()
 
     with cluster() as (scheduler, [a, b]):
@@ -361,3 +501,25 @@ def test_calls_progress_callback(pd_entities, relationships):
 
     assert np.isclose(mock_progress_callback.total_update, 100.0)
     assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
+
+
+def test_dask_kwargs(pd_entities, relationships):
+    cutoff_times_df = pd.DataFrame({"instance_id": [1, 2, 3],
+                                    "time": [10, 12, 15]})
+    feature_matrix, features = dfs(entities=pd_entities,
+                                   relationships=relationships,
+                                   target_entity="transactions",
+                                   cutoff_time=cutoff_times_df)
+
+    with cluster() as (scheduler, [a, b]):
+        dask_kwargs = {'cluster': scheduler['address']}
+        feature_matrix_2, features_2 = dfs(entities=pd_entities,
+                                           relationships=relationships,
+                                           target_entity="transactions",
+                                           cutoff_time=cutoff_times_df,
+                                           dask_kwargs=dask_kwargs)
+
+    assert all(f1.unique_name() == f2.unique_name() for f1, f2 in zip(features, features_2))
+    for column in feature_matrix:
+        for x, y in zip(feature_matrix[column], feature_matrix_2[column]):
+            assert ((pd.isnull(x) and pd.isnull(y)) or (x == y))
